"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
var graphql_transformer_core_1 = require("graphql-transformer-core");
var graphql_mapping_template_1 = require("graphql-mapping-template");
var graphql_transformer_common_1 = require("graphql-transformer-common");
var DefaultValueTransformer = /** @class */ (function (_super) {
    __extends(DefaultValueTransformer, _super);
    function DefaultValueTransformer() {
        var _this = _super.call(this, 'DefaultValueTransformer', "directive @default(value: String) on FIELD_DEFINITION") || this;
        /**
         * When a field is annotated with @default(value: "value") the mapping template will default if not set by the user.
         *
         * Usage:
         *
         * type Post @model {
         *   id: ID!
         *   title: String @default(value: "Hello World")
         *   version: Int!
         * }
         *
         * If a value is set by the client, use that, otherwise
         * default to what is in the value of the @default directive.
         */
        _this.field = function (parent, def, directive, ctx) {
            // @versioned may only be used on types that are also @model
            var modelDirective = parent.directives.find(function (dir) { return dir.name.value === 'model'; });
            if (!modelDirective) {
                throw new graphql_transformer_core_1.InvalidDirectiveError('Fields annotated with @default must also belong to types annotated with @model.');
            }
            if (directive.arguments.length != 1) {
                throw new graphql_transformer_core_1.InvalidDirectiveError('Fields annotated with @default must declare a single argument and value.');
            }
            var defaultArgValue;
            var fieldType;
            if (directive.arguments[0].value.value) {
                defaultArgValue = directive.arguments[0].value.value;
            }
            else {
                throw new graphql_transformer_core_1.InvalidDirectiveError('Directive for @default must declare a value property');
            }
            if (def.type.name.value) {
                fieldType = def.type.name.value;
            }
            else {
                throw new graphql_transformer_core_1.InvalidDirectiveError('Directive for @default must declare a value property');
            }
            var defaultValue;
            switch (fieldType) {
                case "String":
                    defaultValue = "\"" + defaultArgValue + "\"";
                    break;
                case "Int":
                    defaultValue = "" + defaultArgValue;
                    break;
                default:
                    throw new graphql_transformer_core_1.InvalidDirectiveError('Fields annotated with @default must declare a single argument and value.');
            }
            var typeName = parent.name.value;
            var fieldName = def.name.value;
            _this.augmentCreateMutation(ctx, typeName, fieldName, defaultValue);
        };
        return _this;
    }
    /**
     * Set the field to the default value on create if not set otherwise.
     * @param ctx
     * @param typeName
     * @param fieldName
     * @param defaultValue
     */
    DefaultValueTransformer.prototype.augmentCreateMutation = function (ctx, typeName, fieldName, defaultValue) {
        var snippet = graphql_mapping_template_1.printBlock("Setting \"" + fieldName + "\" to default to " + defaultValue)(graphql_mapping_template_1.iff(graphql_mapping_template_1.raw("$util.isNull($ctx.args.input." + fieldName + ")"), graphql_mapping_template_1.qref("$ctx.args.input.put(\"" + fieldName + "\", " + defaultValue + ")")));
        var mutationResolverLogicalId = graphql_transformer_common_1.ResolverResourceIDs.DynamoDBCreateResolverResourceID(typeName);
        var resolver = ctx.getResource(mutationResolverLogicalId);
        if (resolver) {
            resolver.Properties.RequestMappingTemplate = snippet + '\n\n' + resolver.Properties.RequestMappingTemplate;
            ctx.setResource(mutationResolverLogicalId, resolver);
        }
    };
    return DefaultValueTransformer;
}(graphql_transformer_core_1.Transformer));
exports.DefaultValueTransformer = DefaultValueTransformer;
//# sourceMappingURL=DefaultValueTransformer.js.map