"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var graphql_1 = require("graphql");
var graphql_transformer_core_1 = require("graphql-transformer-core");
var graphql_transformer_common_1 = require("graphql-transformer-common");
var DefaultValueTransformer_1 = require("../DefaultValueTransformer");
var graphql_appsync_transformer_1 = require("graphql-appsync-transformer");
var graphql_dynamodb_transformer_1 = require("graphql-dynamodb-transformer");
var getType = function (schemaDoc) { return function (name) {
    return schemaDoc.definitions.find(function (d) { return d.kind !== graphql_1.Kind.SCHEMA_DEFINITION ? d.name.value === name : false; });
}; };
var getField = function (input, field) { return input.fields.find(function (f) { return f.name.value === field; }); };
test('Test DefaultValueTransformer validation happy case', function () {
    var validSchema = "\n    type Post @model {\n        id: ID!\n        title: String @default(value: \"hello world\")\n        viewCount: Int @default(value: \"9001\")\n        createdAt: String\n        updatedAt: String\n    }\n    ";
    var transformer = new graphql_transformer_core_1.default({
        transformers: [
            new graphql_appsync_transformer_1.default(),
            new graphql_dynamodb_transformer_1.default(),
            new DefaultValueTransformer_1.DefaultValueTransformer()
        ]
    });
    var out = transformer.transform(validSchema);
    // tslint:disable-next-line
    var schemaDoc = graphql_1.parse(out.Resources[graphql_transformer_common_1.ResourceConstants.RESOURCES.GraphQLSchemaLogicalID].Properties.Definition);
    expect(out).toBeDefined();
    expect(getField(getType(schemaDoc)('Post'), 'title')).toBeDefined();
    var postCreateMappingTemplate = out.Resources[graphql_transformer_common_1.ResolverResourceIDs.DynamoDBCreateResolverResourceID('Post')].Properties.RequestMappingTemplate;
    var titleSnippet = "#if( $util.isNull($ctx.args.input.viewCount) )\n$util.qr($ctx.args.input.put(\"viewCount\", 9001))\n#end";
    var viewCountSnippet = "#if( $util.isNull($ctx.args.input.title) )\n$util.qr($ctx.args.input.put(\"title\", \"hello world\"))\n#end";
    expect(postCreateMappingTemplate).toContain(titleSnippet);
    expect(postCreateMappingTemplate).toContain(viewCountSnippet);
});
//# sourceMappingURL=DefaultValueTransformer.test.js.map